package org.vraptor.mydvds.dao;

import java.util.List;

import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;
import org.vraptor.mydvds.model.Dvd;

/**
 * Data Access Object referente a entidade Dvd.
 */
public class DvdDao {

	//sessão atual do hibernate
	private Session session;

	/**
	 * Cria um novo DvdDao.
	 *
	 * @param session sessão do hibernate
	 */
	DvdDao(Session session) {
		this.session = session;
	}

	/**
	 * Adiciona um dvd no banco de dados.
	 *
	 * @param dvd
	 */
	public void add(Dvd dvd) {
		//salva o dvd na banca de dados pela sessão do hibernate
		session.save(dvd);
	}

	/**
	 * Devolve uma lista de DvD's que possui um titulo.
	 *
	 * @param title titulo a procurar
	 * @return lista de Dvd's
	 */
	@SuppressWarnings("unchecked")
	public List<Dvd> searchSimilarTitle(String title) {
		//cria um criterio baseado na classe Dvd e adiciona
		//a restrição "titulo" e devolve uma lista de dvds
		return session.createCriteria(Dvd.class).add(
				Restrictions.ilike("title", "%" + title + "%")).list();
	}

}
