package org.vraptor.mydvds.dao;

import org.apache.log4j.Logger;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.AnnotationConfiguration;
import org.hibernate.tool.hbm2ddl.SchemaExport;
import org.hibernate.tool.hbm2ddl.SchemaUpdate;

/**
 * Fábrica que lê as configuração (xml e anotações), criar e fechar a sessão do hibernate.  
 */
public class HibernateSessionFactory {

	private static final Logger logger = Logger
			.getLogger(HibernateSessionFactory.class);

	//fábrica de sessões
	private static final SessionFactory sessionFactory;

	//objeto de configuração de anotações 
	private static final AnnotationConfiguration configuration;

	/*
	 * bloco estático que verifique as classes encontradas no arquivo hibernate.cfg.xml
	 * e lê as anotações para criar uma fábrica de sessões;
	 * como um bloco é estático, elá será executado no deploy quando a aplicação iniciar
	 */
	static {
		try {
			configuration = new AnnotationConfiguration();
			configuration.configure();
			sessionFactory = configuration.buildSessionFactory();
		} catch (Throwable ex) {
			logger.fatal("Something happened here!!! 8-O", ex);
			throw new ExceptionInInitializerError(ex);
		}
	}

	/*
	 * Devolve a fábrica de sessões
	 * @Return a fábrica
	 */
	static SessionFactory getSessionFactory() {
		return sessionFactory;
	}

	/**
	 * Criar o banco de dados baseado nas anotações.
	 */
	public static void create() {
		new SchemaExport(configuration).create(true, true);
	}

	/**
	 * Atualiza a esquema do banco de dados. 
	 */
	public static void update() {
		new SchemaUpdate(configuration).execute(true, true);
	}

	/**
	 * Fecha a sessão.
	 */
	public static void close() {
		sessionFactory.close();
	}

	/**
	 * Devolve a sessão.
	 * @Return a sessão
	 */
	public static Session getSession() {
		return sessionFactory.openSession();
	}

}