package org.vraptor.mydvds.interceptor;

import java.io.IOException;

import javax.servlet.http.HttpServletResponse;

import org.vraptor.Interceptor;
import org.vraptor.LogicException;
import org.vraptor.LogicFlow;
import org.vraptor.mydvds.model.User;
import org.vraptor.view.ViewException;

/**
 * Interceptador para verificar se usuário está na sessão.
 *
 * Lógicas anotadas com esse interceptador (usando <code>@InterceptedBy(AuthorizationInterceptor.class</code>)
 * vão passar pelo método intercept(..) nessa classe.
 */
public class AuthorizationInterceptor implements Interceptor {


	private final HttpServletResponse response;

	public AuthorizationInterceptor(HttpServletResponse response) {
		this.response = response;
	}

	/**
	 * Intercepta a requisição da lógica e verifique o usuário na sessão.
	 *
	 * @param flow útil para acessar o logic request
	 */
	public void intercept(LogicFlow flow) throws LogicException, ViewException {

		/*
		 * Busca o usuário na sessão.
		 * A sessão está acessível pelo logic request do vraptor.
		 */
		User user = (User) flow.getLogicRequest().getSessionContext()
				.getAttribute("currentUser");

		if (user == null) {
				this.response.setHeader("SessionTimeOut", "The Session has expired");
			throw new LogicException(new AuthenticationException("The Session has expired"));
		} else {
			//continua executando
			flow.execute();
		}

	}

}
