package org.vraptor.mydvds.interceptor;

import org.vraptor.Interceptor;
import org.vraptor.LogicException;
import org.vraptor.LogicFlow;
import org.vraptor.annotations.Out;
import org.vraptor.mydvds.dao.DaoFactory;
import org.vraptor.mydvds.dao.HibernateSessionFactory;
import org.vraptor.view.ViewException;

/**
 * Interceptador para criar uma fábrica de daos.
 * 
 * Componentes que usam esse interceptador (@InterceptedBy(DaoInterceptor.class)
 * vão passar pelo método intercept(...) nessa classe. Eles recebem a fábrica que dá
 * acesso nos daos e banco de dados.
 */
public class DaoInterceptor implements Interceptor {

	/*
	 * @Out(key = "org.vraptor.mydvds.dao.DaoFactory") ejeta a fábrica com a chave definida. 
	 * 
	 * Os componentes podem injetar ela pelo construtor 
	 * ou usando @In(key = "org.vraptor.mydvds.dao.DaoFactory")
	 */
	@Out(key = "org.vraptor.mydvds.dao.DaoFactory")
	private DaoFactory factory;

	/**
	 * O método cria uma nova fábrica de daos e chama <code>flow.execute();</code>
	 * para continuar a execução do request. 
	 * 
	 * Depois da execução ele verifica se existir uma transação aberta 
	 * (e faz um rollback se for necessário).
	 *  
	 * Finalmente o método fecha a sessão.    
	 * 
	 * @param flow 
	 */
	public void intercept(LogicFlow flow) throws LogicException, ViewException {
		factory = new DaoFactory(HibernateSessionFactory.getSession());
		try {
			flow.execute();
		} catch (LogicException e) {
			throw e;
		} finally {
			if (factory.hasTransaction()) {
				factory.rollback();
			}
			factory.close();
		}
	}
}
