package org.vraptor.mydvds.logic;

import org.vraptor.annotations.Component;
import org.vraptor.annotations.In;
import org.vraptor.annotations.InterceptedBy;
import org.vraptor.mydvds.dao.DaoFactory;
import org.vraptor.mydvds.interceptor.AuthorizationInterceptor;
import org.vraptor.mydvds.interceptor.DaoInterceptor;
import org.vraptor.mydvds.model.User;
import org.vraptor.scope.ScopeType;

/**
 * A classe HomeComponent, nome do componente "user".
 *
 * Será interceptada pelo <code>DaoInterceptor</code> e <code>AuthorizationInterceptor</code>.
 */
@Component("user")
@InterceptedBy( { AuthorizationInterceptor.class, DaoInterceptor.class })
public class HomeComponent {

	private DaoFactory factory;

	/*
	 * Injeta o usario da sessão usando a anotação @In.
	 * É igual httpSession.getAttribute("currentUser");
	 *
	 * Podemos ter certeza que o usuario está na sessão,
	 * porque chamamos <code>AuthorizationInterceptor</code> antes.
	 */
	@In(scope = ScopeType.SESSION)
	private User currentUser;

	/**
	 * Cria a lógica e injeta a fábrica de daos pelo construtor.
	 *
	 * Podemos usar injeção pelo construtor por causa do
	 * <code>DaoInterceptor.class</code> que criar e ejetar a fábrica.
	 *
	 * @param factory
	 */
	public HomeComponent(DaoFactory factory) {
		this.factory = factory;
	}

	/**
	 * URL: 	user.home.logic
	 * View: 	user.home.ok (user/home.ok.jsp)
	 *
	 * O método atualiza o estado do usuario.
	 */
	public void home() {
		factory.getUserDao().refresh(currentUser);
	}

}
