package org.vraptor.mydvds.logic;

import org.vraptor.annotations.Component;
import org.vraptor.annotations.In;
import org.vraptor.annotations.InterceptedBy;
import org.vraptor.annotations.Parameter;
import org.vraptor.mydvds.dao.DaoFactory;
import org.vraptor.mydvds.interceptor.AuthorizationInterceptor;
import org.vraptor.mydvds.interceptor.DaoInterceptor;
import org.vraptor.mydvds.model.User;

/**
 * A classe SingleDvdComponent, nome do componente "user". 
 * 
 * A classe será interceptada pelo <code>DaoInterceptor</code> e 
 * <code>AuthorizationInterceptor</code> 
 */
@Component("user")
@InterceptedBy( { DaoInterceptor.class, AuthorizationInterceptor.class })
public class ViewUserComponent {

	/*
	 * Usamos @In invés do injeção pelo construtor.
	 * Precisamos definir o key.
	 */
	@In(key = "org.vraptor.mydvds.dao.DaoFactory")
	private DaoFactory factory;

	/* 
	 * @Parameter lê a parâmetro da requisição com o key "user",
	 * por exemplo: 
	 * 
	 * 		suer.view.logic?user.id=1
	 * 
	 * preenche automaticamente o atributo id do user com o valor "1"
	 * 
	 */
	@Parameter
	private User user = new User();

	/**
	 * URL: 			user.view.logic
	 * View ok:			user.view.ok (user/view.ok.jsp)
	 */
	public void view() {
		this.factory.getUserDao().refresh(user);
	}
	
	/**
	 * Ejeção do objeto user pelo getter. Podemos acessar o usuário no view user/view.ok.jsp,
	 * por exemplo: ${user.name}
	 * 
	 * @return o usuário
	 */
	public User getUser() {
		return user;
	}

}
